Index: /trunk/anuga_core/demos/channel3.py
===================================================================
--- /trunk/anuga_core/demos/channel3.py	(revision 9308)
+++ /trunk/anuga_core/demos/channel3.py	(revision 9309)
@@ -20,4 +20,5 @@
 domain = anuga.Domain(points, vertices, boundary)
 domain.set_name('channel3')                  # Output name
+domain.set_flow_algorithm('DE0')
 print domain.statistics()
 
Index: /trunk/anuga_core/demos/channel3_parallel.py
===================================================================
--- /trunk/anuga_core/demos/channel3_parallel.py	(revision 9308)
+++ /trunk/anuga_core/demos/channel3_parallel.py	(revision 9309)
@@ -9,5 +9,5 @@
 import anuga
 
-import anuga_parallel
+#import anuga_parallel
 
 
@@ -46,9 +46,10 @@
 
 
-if anuga_parallel.myid == 0:
+if anuga.myid == 0:
     points, vertices, boundary = anuga.rectangular_cross(int(length/dx),
                                          int(width/dy), len1=length, len2=width)
     domain = anuga.Domain(points, vertices, boundary)
     domain.set_name('channel3')                  # Output name
+    domain.set_flow_algorithm('DE0')
     print domain.statistics()
 
@@ -64,6 +65,6 @@
 # Distribute domain on processor 0 to to other processors
 #------------------------------------------------------------------------------
-parameters = dict(ghost_layer_width=3)
-domain = anuga_parallel.distribute(domain, verbose= True, parameters=parameters)
+#parameters = dict(ghost_layer_width=3)
+domain = anuga.distribute(domain, verbose= True)
 
 
@@ -81,5 +82,5 @@
 #------------------------------------------------------------------------------
 for t in domain.evolve(yieldstep=0.1, finaltime=16.0):
-    if anuga_parallel.myid == 0:
+    if anuga.myid == 0:
         print domain.timestepping_statistics()
 
@@ -93,4 +94,4 @@
 domain.sww_merge(verbose=True)
 
-anuga_parallel.finalize()
+anuga.finalize()
         
Index: /trunk/anuga_core/source/anuga/__init__.py
===================================================================
--- /trunk/anuga_core/source/anuga/__init__.py	(revision 9308)
+++ /trunk/anuga_core/source/anuga/__init__.py	(revision 9309)
@@ -72,4 +72,5 @@
 from anuga.utilities.file_utils import copy_code_files
 from anuga.utilities.numerical_tools import safe_acos as acos
+import anuga.utilities.plot_utils as plot_utils
 
 
Index: /trunk/anuga_core/source/anuga/damage_modelling/inundation_damage.py
===================================================================
--- /trunk/anuga_core/source/anuga/damage_modelling/inundation_damage.py	(revision 9308)
+++ /trunk/anuga_core/source/anuga/damage_modelling/inundation_damage.py	(revision 9309)
@@ -42,6 +42,7 @@
 from anuga.geospatial_data.geospatial_data import ensure_absolute
 from anuga.utilities.numerical_tools import NAN
+from anuga.config import epsilon
 import anuga.utilities.log as log
-from config import epsilon
+
 depth_epsilon = epsilon
 
Index: /trunk/anuga_core/source/anuga/validation_utilities/__init__.py
===================================================================
--- /trunk/anuga_core/source/anuga/validation_utilities/__init__.py	(revision 9308)
+++ /trunk/anuga_core/source/anuga/validation_utilities/__init__.py	(revision 9309)
@@ -11,4 +11,5 @@
 from run_validation import run_validation_script
 from produce_report import produce_report
+from save_parameters_tex import save_parameters_tex
 
 

Index: /trunk/anuga_core/source/anuga/utilities/plot_utils.py
===================================================================
--- /trunk/anuga_core/source/anuga/utilities/plot_utils.py	(revision 9308)
+++ /trunk/anuga_core/source/anuga/utilities/plot_utils.py	(revision 9309)
@@ -4,11 +4,11 @@
     Functionality of note:
 
     util.get_outputs -- read the data from a single sww file
     into a single object
     
     util.combine_outputs -- read the data from a list of sww
     files into a single object
     
     util.near_transect -- for finding the indices of points
                           'near' to a given line, and
                           assigning these points a
@@ -18,25 +18,25 @@
     transect (e.g. a channel cross-section) -- see example below
 
     util.sort_sww_filenames -- match sww filenames by a wildcard, and order
                                them according to their 'time'. This means that
                                they can be stuck together using
                                'combine_outputs' correctly
 
     util.triangle_areas -- compute the areas of every triangle
                            in a get_outputs object [ must be vertex-based]
 
     util.water_volume -- compute the water volume at every
                          time step in an sww file (needs both
                          vertex and centroid value input). 
 
     util.Make_Geotiff -- convert sww centroids to a georeferenced tiff
  
     Here is an example ipython session which uses some of these functions:
 
-    > import util
+    > from anuga import plot_utils
     > from matplotlib import pyplot as pyplot
-    > p=util.get_output('myfile.sww',minimum_allowed_height=0.01)
-    > p2=util.get_centroids(p,velocity_extrapolation=True)
-    > xxx=util.near_transect(p,[95., 85.], [120.,68.],tol=2.) # Could equally well use p2
+    > p=plot_utils.get_output('myfile.sww',minimum_allowed_height=0.01)
+    > p2=plot_utils.get_centroids(p,velocity_extrapolation=True)
+    > xxx=plot_utils.near_transect(p,[95., 85.], [120.,68.],tol=2.) # Could equally well use p2
     > pyplot.ion() # Interactive plotting
     > pyplot.scatter(xxx[1],p.vel[140,xxx[0]],color='red') # Plot along the transect
@@ -143,5 +143,5 @@
     """Read in data from an .sww file in a convenient form
        e.g. 
-        p = util.get_output('channel3.sww', minimum_allowed_height=0.01)
+        p = plot_utils.get_output('channel3.sww', minimum_allowed_height=0.01)
         
        p then contains most relevant information as e.g., p.stage, p.elev, p.xmom, etc 
@@ -153,5 +153,5 @@
                 self.xvel, self.yvel, self.vel, self.minimum_allowed_height,\
                 self.xllcorner, self.yllcorner, self.timeSlices = \
-                read_output(filename, minimum_allowed_height,copy.copy(timeSlices))
+                _read_output(filename, minimum_allowed_height,copy.copy(timeSlices))
         self.filename = filename
         self.verbose = verbose
@@ -197,5 +197,5 @@
 ############################################################################
 
-def read_output(filename, minimum_allowed_height, timeSlices):
+def _read_output(filename, minimum_allowed_height, timeSlices):
     """
      Purpose: To read the sww file, and output a number of variables as arrays that 
@@ -314,13 +314,13 @@
     Extract centroid values from the output of get_output, OR from a
         filename  
-    See read_output or get_centroid_values for further explanation of
+    See _read_output or _get_centroid_values for further explanation of
         arguments
     e.g.
         # Case 1 -- get vertex values first, then centroids
-        p = util.get_output('my_sww.sww', minimum_allowed_height=0.01) 
+        p = plot_utils.get_output('my_sww.sww', minimum_allowed_height=0.01) 
         pc=util.get_centroids(p, velocity_extrapolation=True) 
 
         # Case 2 -- get centroids directly
-        pc=util.get_centroids('my_sww.sww', velocity_extrapolation=True) 
+        pc=plot_utils.get_centroids('my_sww.sww', velocity_extrapolation=True) 
 
     NOTE: elevation is only stored once in the output, even if it was
@@ -337,5 +337,5 @@
              self.ymom, self.height, self.elev, self.friction, self.xvel,\
              self.yvel, self.vel, self.xllcorner, self.yllcorner, self.timeSlices= \
-             get_centroid_values(p, velocity_extrapolation,\
+             _get_centroid_values(p, velocity_extrapolation,\
                          timeSlices=copy.copy(timeSlices),\
                          minimum_allowed_height=minimum_allowed_height,\
@@ -343,5 +343,5 @@
                                  
 
-def get_centroid_values(p, velocity_extrapolation, verbose, timeSlices, 
+def _get_centroid_values(p, velocity_extrapolation, verbose, timeSlices, 
                         minimum_allowed_height):
     """
@@ -363,7 +363,7 @@
     
            timeSlices = list of integer indices when we want output for, or
-                        'all' or 'last' or 'max'. See read_output
-    
-           minimum_allowed_height = height at which velocities are zeroed. See read_output
+                        'all' or 'last' or 'max'. See _read_output
+    
+           minimum_allowed_height = height at which velocities are zeroed. See _read_output
     
      Output: Values of x, y, Stage, xmom, ymom, elev, xvel, yvel, vel etc at centroids
@@ -820,5 +820,5 @@
 def Make_Geotif(swwFile=None, 
              output_quantities=['depth'],
-             myTimeStep=0, CellSize=5.0, 
+             myTimeStep=0, CellSize=100.0, 
              lower_left=None, upper_right=None,
              EPSG_CODE=None, 
@@ -4,11 +4,11 @@
     Functionality of note:
 
-    util.get_outputs -- read the data from a single sww file
+    plot_utils.get_outputs -- read the data from a single sww file
     into a single object
     
@@ -4,11 +4,11 @@
     into a single object
     
-    util.combine_outputs -- read the data from a list of sww
+    plot_utils.combine_outputs -- read the data from a list of sww
     files into a single object
     
@@ -4,11 +4,11 @@
     files into a single object
     
-    util.near_transect -- for finding the indices of points
+    plot_utils.near_transect -- for finding the indices of points
                           'near' to a given line, and
                           assigning these points a
@@ -18,25 +18,25 @@
     transect (e.g. a channel cross-section) -- see example below
 
-    util.sort_sww_filenames -- match sww filenames by a wildcard, and order
+    plot_utils.sort_sww_filenames -- match sww filenames by a wildcard, and order
                                them according to their 'time'. This means that
                                they can be stuck together using
@@ -18,25 +18,25 @@
                                'combine_outputs' correctly
 
-    util.triangle_areas -- compute the areas of every triangle
+    plot_utils.triangle_areas -- compute the areas of every triangle
                            in a get_outputs object [ must be vertex-based]
 
@@ -18,25 +18,25 @@
                            in a get_outputs object [ must be vertex-based]
 
-    util.water_volume -- compute the water volume at every
+    plot_utils.water_volume -- compute the water volume at every
                          time step in an sww file (needs both
                          vertex and centroid value input). 
@@ -18,25 +18,25 @@
                          vertex and centroid value input). 
 
-    util.Make_Geotiff -- convert sww centroids to a georeferenced tiff
+    plot_utils.Make_Geotif -- convert sww centroids to a georeferenced tiff
  
     Here is an example ipython session which uses some of these functions: